@@ -9,6 +9,11 @@ fn main() {
                     .expect("No filename provided as second argument."),
             )
             .unwrap();
+            let test = requests::get_instrument_text(mod_id).unwrap();
+            println!("{}", test);
+
+            println!("\n----------------------------------------\n");
+
             let mod_info = requests::get_full_details_as_struct(mod_id);
             println!("{:#?}", mod_info);
             /* or if you want it pre-formatted as csv:
